@@ -1,4 +1,3 @@
-
 try:
 
     import logging
@@ -33,13 +32,12 @@ class TokenType(enum.Enum):
     This class used to give token type.
     """
 
-    grant = Constants.GRANT
+    GRANT = Constants.GRANT
 
-    refresh = Constants.REFRESH
+    REFRESH = Constants.REFRESH
 
 
 class OAuthToken(Token):
-
     """
     This class to get tokens and check expire time.
     """
@@ -50,11 +48,13 @@ class OAuthToken(Token):
 
         """
         Creates an OAuthToken class instance with the specified parameters.
-        :param client_id: A str containing the OAuth client id.
-        :param client_secret: A str containing the OAuth client secret.
-        :param redirect_url: A str containing the OAuth redirect URL.
-        :param token: A str containing the REFRESH/GRANT token.
-        :param token_type: A class containing the given token type.
+
+        Parameters:
+            client_id (str) : A string containing the OAuth client id.
+            client_secret (str) : A string containing the OAuth client secret.
+            redirect_url (str) : A string containing the OAuth redirect URL. Can be None
+            token (str) : A string containing the REFRESH/GRANT token.
+            token_type (TokenType) : An enum containing the given token type.
         """
 
         error = {}
@@ -94,8 +94,8 @@ class OAuthToken(Token):
             self.client_id = client_id
             self.client_secret = client_secret
             self.redirect_url = redirect_url
-            self.grant_token = token if (token_type == TokenType.grant) else None
-            self.refresh_token = token if (token_type == TokenType.refresh) else None
+            self.grant_token = token if (token_type == TokenType.GRANT) else None
+            self.refresh_token = token if (token_type == TokenType.REFRESH) else None
             self.access_token = None
             self.expires_in = None
 
@@ -110,7 +110,8 @@ class OAuthToken(Token):
         oauth_token = store.get_token(initializer.user, self)
 
         if oauth_token is None:
-            token = self.generate_access_token(user, store).access_token if (self.refresh_token is None) else self.refresh_access_token(user, store).access_token
+            token = self.generate_access_token(user, store).access_token if (
+                        self.refresh_token is None) else self.refresh_access_token(user, store).access_token
 
         elif int(oauth_token.expires_in) - int(time.time() * 1000) < 5000:
             OAuthToken.logger.info(Constants.REFRESH_TOKEN_MESSAGE)
@@ -119,7 +120,7 @@ class OAuthToken(Token):
         else:
             token = oauth_token.access_token
 
-        url_connection.headers[Constants.AUTHORIZATION] = Constants.OAUTH_HEADER_PREFIX + token
+        url_connection.add_header(Constants.AUTHORIZATION, Constants.OAUTH_HEADER_PREFIX + token)
 
     def refresh_access_token(self, user, store):
         try:
@@ -171,7 +172,7 @@ class OAuthToken(Token):
     def parse_response(self, response):
         response_json = dict(response)
 
-        if not Constants.ACCESS_TOKEN in response_json:
+        if Constants.ACCESS_TOKEN not in response_json:
             OAuthToken.logger.error(Constants.GET_TOKEN_ERROR)
             raise SDKException(code=Constants.INVALID_CLIENT_ERROR, message=str(response_json.get(Constants.ERROR_KEY)))
 
@@ -184,4 +185,5 @@ class OAuthToken(Token):
         return self
 
     def get_token_expires_in(self, response):
-        return int(response[Constants.EXPIRES_IN]) if Constants.EXPIRES_IN_SEC in response else int(response[Constants.EXPIRES_IN]) * 1000
+        return int(response[Constants.EXPIRES_IN]) if Constants.EXPIRES_IN_SEC in response else int(
+            response[Constants.EXPIRES_IN]) * 1000
