@@ -21,7 +21,7 @@ except Exception as e:
 class FileStore(TokenStore):
 
     """
-    This class to store user token details to the file.
+    The class to store user token details to the file.
     """
 
     logger = logging.getLogger('SDKLogger')
@@ -30,8 +30,12 @@ class FileStore(TokenStore):
 
         """
         Creates an FileStore class instance with the specified parameters.
-        :param file_path: A str containing the token store file path.
+
+        Parameters:
+            file_path (str) : A string containing the absolute file path of the file to store tokens
+
         """
+
         self.file_path = file_path
 
         if (os.path.exists(file_path) and os.stat(file_path).st_size == 0) or not os.path.exists(file_path):
