@@ -13,10 +13,12 @@ class SDKException(Exception):
 
         """
         Creates an SDKException class instance with the specified parameters.
-        :param code: A str containing the Exception error code.
-        :param message: A str containing the Exception error message.
-        :param details: A JSON Object containing the error response.
-        :param cause: A Exception class instance.
+
+        Parameters:
+            code (str) : A string containing the Exception error code.
+            message (str) : A string containing the Exception error message.
+            details (dict) : A dict containing the error response.
+            cause (Exception) : A Exception class instance.
         """
 
         self.code = code
