@@ -4,26 +4,31 @@ from . import util
 from .header import Header
 from .header_map import HeaderMap
 from .param import Param
-from .param_map import ParameterMap
+from .parameter_map import ParameterMap
 from .initializer import Initializer
-from .user import User
+from .user_signature import UserSignature
 from . import contact_roles
-from . import users
 from . import modules
-from . import fields
-from . import record
-from . import layouts
-from . import custom_view
-from . import related_list
-from . import organization
-from . import role
-from . import profile
-from . import taxes
-from . import tags
-from . import variable_groups
+from . import attachments
+from . import bulk_read
 from . import variables
 from . import notes
-from . import attachments
+from . import org
+from . import roles
+from . import related_lists
+from . import profiles
+from . import taxes
+from . import layouts
+from . import bulk_write
+from . import users
+from . import custom_views
+from . import tags
+from . import territories
+from . import share_records
+from . import fields
+from . import variable_groups
+from . import currencies
+from . import related_records
+from . import record
 from . import blue_print
-from . import bulk_read
-from . import bulk_write
\ No newline at end of file
+from . import file
\ No newline at end of file
