@@ -1,13 +1,15 @@
 try:
     from zcrmsdk.src.com.zoho.crm.api.util.header_param_validator import HeaderParamValidator
+    from zcrmsdk.src.com.zoho.crm.api.header import Header
 except Exception:
     from .util import HeaderParamValidator
+    from .header import Header
 
 
 class HeaderMap(object):
 
     """
-    This class representing the HTTP header name and value.
+    This class represents the HTTP header name and value.
     """
 
     def __init__(self):
@@ -18,13 +20,14 @@ class HeaderMap(object):
     def add(self, header, value):
 
         """
-        This method to add header name and value.
-        :param header: A Header class instance.
-        :param value: A object containing the header value.
+        This method to add parameter name and value.
+
+        Parameters:
+            header (Header): A Header class instance.
+            value (object): An object containing the header value.
         """
 
         name = header.name
-
         class_name = header.class_name
 
         if class_name is not None:
@@ -32,7 +35,7 @@ class HeaderMap(object):
 
         if name not in self.header_map:
             self.header_map[name] = str(value)
+
         else:
             header_value = self.header_map[name]
-
             self.header_map[name] = header_value + ',' + str(value)
