@@ -1,8 +1,7 @@
 from .action_wrapper import ActionWrapper
-from .users_operations import UsersOperations,UsersOperations,GetUsersParam
-from .role import Role
+from .users_operations import UsersOperations, GetUsersParam, GetUsersHeader, GetUserHeader
 from .customize_info import CustomizeInfo
-from .profile import Profile
+from .shift import Shift
 from .body_wrapper import BodyWrapper
 from .api_exception import APIException
 from .action_response import ActionResponse
@@ -14,3 +13,4 @@ from .theme import Theme
 from .action_handler import ActionHandler
 from .user import User
 from .territory import Territory
+from .info import Info
