@@ -2,7 +2,8 @@
 try:
     import json
     import platform
-    import urllib
+    import urllib3
+    import logging
     from zcrmsdk.src.com.zoho.crm.api.util.api_http_connector import APIHTTPConnector
     from zcrmsdk.src.com.zoho.crm.api.util.json_converter import JSONConverter
     from zcrmsdk.src.com.zoho.crm.api.util.xml_converter import XMLConverter
@@ -19,7 +20,8 @@ try:
 except Exception:
     import json
     import platform
-    import urllib
+    import urllib3
+    import logging
     from .api_http_connector import APIHTTPConnector
     from .json_converter import JSONConverter
     from .constants import Constants
@@ -39,6 +41,7 @@ class CommonAPIHandler(object):
     The Request parameter, header and body objects are constructed here.
     Process the response JSON and converts it to relevant objects in the library.
     """
+    logger = logging.getLogger('SDKLogger')
 
     def __init__(self):
 
@@ -53,9 +56,11 @@ class CommonAPIHandler(object):
     def add_param(self, param_name, param_value):
 
         """
-        This method to add an API request parameter.
-        :param param_name: A str containing the API request parameter name.
-        :param param_value: A object containing the API request parameter value.
+        The method to add an API request parameter.
+
+        Parameters:
+            param_name (str) : A string containing the API request parameter name.
+            param_value (object) : An object containing the API request parameter value.
         """
 
         if self.param is None:
@@ -66,9 +71,11 @@ class CommonAPIHandler(object):
     def add_header(self, header_name, header_value):
 
         """
-        This method to add an API request header.
-        :param header_name: A str containing the API request header name.
-        :param header_value: A object containing the API request header value.
+        The method to add an API request header.
+
+        Parameters:
+            header_name (str) : A string containing the API request header name.
+            header_value (object) : An object containing the API request header value.
         """
 
         if self.header is None:
@@ -90,7 +97,12 @@ class CommonAPIHandler(object):
             from ..initializer import Initializer
 
         connector = APIHTTPConnector()
-        self.set_api_url(connector)
+        try:
+            self.set_api_url(connector)
+        except SDKException as e:
+            CommonAPIHandler.logger.info(Constants.SET_API_URL_EXCEPTION + e.__str__())
+            return None
+
         connector.request_method = self.http_method
         connector.content_type = self.content_type
 
@@ -100,59 +112,48 @@ class CommonAPIHandler(object):
         if self.param is not None and len(self.param.parameter_map) > 0:
             connector.parameters = self.param.parameter_map
 
-        Initializer.get_initializer().token.authenticate(connector)
+        try:
+            Initializer.get_initializer().token.authenticate(connector)
+        except SDKException as e:
+            CommonAPIHandler.logger.info(Constants.AUTHENTICATION_EXCEPTION + e.__str__())
+            return None
+
         convert_instance = None
 
         if self.content_type is not None and (self.http_method == Constants.REQUEST_METHOD_POST or self.http_method == Constants.REQUEST_METHOD_PUT):
-            convert_instance = self.get_converter_class_instance(self.content_type)
-            request = convert_instance.form_request(self.request, self.request.__class__.__module__, 1)
+            try:
+                convert_instance = self.get_converter_class_instance(self.content_type.lower())
+                request = convert_instance.form_request(self.request, self.request.__class__.__module__, 1)
+            except Exception as e:
+                CommonAPIHandler.logger.info(Constants.FORM_REQUEST_EXCEPTION + e.__str__())
+                return None
+
             connector.request_body = request
 
-        connector.headers[Constants.ZOHO_SDK] = platform.system() + "/" + platform.release() + " python/" + platform.python_version() + ":" + Constants.SDK_VERSION
-        response = connector.fire_request(convert_instance)
-        status_code = response.status_code
-        headers = response.headers
-        content_type = response.headers[Constants.CONTENT_TYPE]
-
-        if ";" in content_type:
-            content_type = content_type.rpartition(";")[0]
-
-        convert_instance = self.get_converter_class_instance(content_type)
-        class_name = str(class_name)
-        return_object = convert_instance.get_wrapped_response(response, class_name)
-
-        return APIResponse(headers, status_code, return_object)
-
-    def set_api_url(self, connector):
         try:
-            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
-        except Exception:
-            from ..initializer import Initializer
+            connector.headers[Constants.ZOHO_SDK] = platform.system() + "/" + platform.release() + " python/" + platform.python_version() + ":" + Constants.SDK_VERSION
+            response = connector.fire_request(convert_instance)
+            status_code = response.status_code
+            headers = response.headers
+            return_object = None
 
-        api_path = ''
+            if Constants.CONTENT_TYPE in headers:
+                content_type = response.headers[Constants.CONTENT_TYPE]
 
-        if 'http' in self.api_path:
-            if 'content.zohoapis.com' in self.api_path:
-                api_path = Initializer.get_initializer().environment.file_upload_url
+                if ";" in content_type:
+                    content_type = content_type.rpartition(";")[0]
 
-                try:
-                    url_parse = urllib.parse.urlparse(self.api_path)
-                    path = url_parse[2]
-                except Exception as ex:
-                    CommonAPIHandler.logger.info("Exception in URL " + str(ex))
-                    raise SDKException(None, None, None, ex)
+                convert_instance = self.get_converter_class_instance(content_type)
+                return_object = convert_instance.get_wrapped_response(response, class_name)
 
-                api_path = api_path + path
             else:
-                if str(self.api_path)[:1].__eq__('/'):
-                    self.api_path = self.api_path[1:]
+                CommonAPIHandler.logger.info(response.__str__())
 
-                api_path = api_path + self.api_path
-        else:
-            api_path = Initializer.get_initializer().environment.url
-            api_path = api_path + self.api_path
+            return APIResponse(headers, status_code, return_object)
+        except Exception as e:
+            CommonAPIHandler.logger.info(Constants.API_CALL_EXCEPTION + e.__str__())
 
-        connector.url = api_path
+        return None
 
     def get_converter_class_instance(self, encode_type):
 
@@ -168,6 +169,8 @@ class CommonAPIHandler(object):
 
             "text/plain": JSONConverter(self),
 
+            "text/html": JSONConverter(self),
+
             "application/xml": XMLConverter(self),
 
             "text/xml": XMLConverter(self),
@@ -187,6 +190,39 @@ class CommonAPIHandler(object):
             "text/csv": Downloader(self),
 
             "image/tiff": Downloader(self),
+
+            "application/octet-stream": Downloader(self),
         }
 
         return switcher.get(encode_type, None)
+
+    def set_api_url(self, connector):
+        try:
+            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+        except Exception:
+            from ..initializer import Initializer
+
+        api_path = ''
+
+        if Constants.HTTP in self.api_path:
+            if Constants.CONTENT_API_URL in self.api_path:
+                api_path = Initializer.get_initializer().environment.file_upload_url
+
+                try:
+                    url_parse = urllib3.util.parse_url(self.api_path)
+                    path = url_parse.path
+                except Exception as ex:
+                    CommonAPIHandler.logger.info("Exception in URL " + str(ex))
+                    raise SDKException(None, None, None, ex)
+
+                api_path = api_path + path
+            else:
+                if str(self.api_path)[:1].__eq__('/'):
+                    self.api_path = self.api_path[1:]
+
+                api_path = api_path + self.api_path
+        else:
+            api_path = Initializer.get_initializer().environment.url
+            api_path = api_path + self.api_path
+
+        connector.url = api_path
