@@ -397,6 +397,8 @@ class Constants(object):
 
     NO_CONTENT_STATUS_CODE = 204
 
+    NOT_MODIFIED_STATUS_CODE = 304
+
     HREF = "href"
 
     API_EXCEPTION = "API_EXCEPTION"
@@ -449,6 +451,20 @@ class Constants(object):
 
     EXCEPTION_SET_KEY_MODIFIED = "Exception in calling set_key_modified : "
 
+    SET_API_URL_EXCEPTION = "Exception in setting API URL : "
+
+    AUTHENTICATION_EXCEPTION = "Exception in authenticating current request : "
+
+    FORM_REQUEST_EXCEPTION = "Exception in forming request body : "
+
+    API_CALL_EXCEPTION = "Exception in current API call execution : "
+
+    HTTP = "http"
+
+    CONTENT_API_URL = "content.zohoapis.com"
+
+    EXCEPTION = "Exception"
+
 
 
 
