@@ -32,18 +32,6 @@ class Downloader(Converter):
         self.unique_dict = {}
         self.common_api_handler = common_api_handler
 
-    def module_to_class(self, module_name):
-        class_name = module_name
-
-        if "_" in module_name:
-            class_name = ''
-            module_split = str(module_name).split('_')
-            for each_name in module_split:
-                each_name = each_name.capitalize()
-                class_name += each_name
-
-        return class_name
-
     def form_request(self, request_object, pack, instance_number):
 
         return None
@@ -62,15 +50,8 @@ class Downloader(Converter):
             from zcrmsdk.src.com.zoho.crm.api import Initializer
 
         except Exception:
-
             from ..initializer import Initializer
 
-        try:
-            response_json = response.json()
-            return JSONConverter(self.common_api_handler).get_wrapped_response(response, pack)
-        except Exception:
-            Downloader.logger.info("")
-
         path_split = str(pack).rpartition(".")
         class_name = self.module_to_class(path_split[-1])
         pack = path_split[0] + "." + class_name
@@ -83,7 +64,7 @@ class Downloader(Converter):
                 if Constants.FILE_BODY_WRAPPER in each_class:
                     return self.get_response(response, each_class)
         else:
-            instance = self.get_class_instance(class_name, path_split[0])()
+            instance = self.get_class(class_name, path_split[0])()
 
             for member_name, member_detail in class_detail.items():
                 data_type = member_detail[Constants.TYPE]
@@ -103,7 +84,7 @@ class Downloader(Converter):
 
                     stream_path_split = str(data_type).rpartition(".")
                     stream_class_name = self.module_to_class(stream_path_split[-1])
-                    instance_value = self.get_class_instance(stream_class_name, stream_path_split[0])(file_name, response)
+                    instance_value = self.get_class(stream_class_name, stream_path_split[0])(file_name, response)
 
                 setattr(instance, self.construct_private_member(class_name=class_name, member_name=member_name), instance_value)
 
@@ -112,7 +93,19 @@ class Downloader(Converter):
     def construct_private_member(self, class_name, member_name):
         return '_' + class_name + '__' + member_name
 
-    def get_class_instance(self, class_name, class_path):
+    def get_class(self, class_name, class_path):
         imported_module = importlib.import_module(class_path)
         class_holder = getattr(imported_module, class_name)
         return class_holder
+
+    def module_to_class(self, module_name):
+        class_name = module_name
+
+        if "_" in module_name:
+            class_name = ''
+            module_split = str(module_name).split('_')
+            for each_name in module_split:
+                each_name = each_name.capitalize()
+                class_name += each_name
+
+        return class_name
