@@ -31,18 +31,8 @@ class JSONConverter(Converter):
         self.unique_dict = {}
         self.common_api_handler = common_api_handler
 
-    def module_to_class(self, module_name):
-        class_name = module_name
-
-        if "_" in module_name:
-            class_name = ''
-            module_split = str(module_name).split('_')
-
-            for each_name in module_split:
-                each_name = each_name.capitalize()
-                class_name += each_name
-
-        return class_name
+    def append_to_request(self, request_base, request_object):
+        return json.dumps(request_object).encode('utf-8')
 
     def form_request(self, request_instance, pack, instance_number):
         path_split = str(pack).rpartition(".")
@@ -86,6 +76,58 @@ class JSONConverter(Converter):
         else:
             return self.is_not_record_request(request_instance, class_name, class_detail, instance_number)
 
+    def is_not_record_request(self, request_instance, class_name, class_detail, instance_number):
+        try:
+            from zcrmsdk.src.com.zoho.crm.api.record import FileDetails
+        except Exception:
+            from ..record import FileDetails
+
+        request_json = {}
+
+        for member_name, member_detail in class_detail.items():
+            modification = None
+
+            if Constants.READ_ONLY in member_name or (Constants.NAME not in member_detail):
+                continue
+
+            key_name = member_detail[Constants.NAME]
+
+            try:
+                modification = getattr(request_instance, Constants.IS_KEY_MODIFIED)(key_name)
+            except Exception as e:
+                JSONConverter.logger.info(Constants.EXCEPTION_IS_KEY_MODIFIED + e.__str__())
+
+            if (modification is None or modification == 0) and Constants.REQUIRED in member_detail and bool(
+                    member_detail[Constants.REQUIRED]):
+                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR,
+                                   Constants.MANDATORY_KEY_MISSING_ERROR + member_name)
+
+            field_value = getattr(request_instance,
+                                  self.construct_private_member(class_name=class_name, member_name=member_name))
+
+            if modification is not None and not modification == 0 and self.value_checker(class_name=class_name,
+                                                                                     member_name=member_name,
+                                                                                     key_details=member_detail,
+                                                                                     value=field_value,
+                                                                                     unique_values_map=self.unique_dict,
+                                                                                     instance_number=instance_number) is True:
+                key_name = member_detail.get(Constants.NAME)
+
+                if isinstance(request_instance, FileDetails):
+                    if key_name.lower() == Constants.ATTACHMENT_ID.lower():
+                        request_json[key_name.lower()] = field_value
+
+                    elif key_name.lower() == Constants.FILE_ID.lower():
+                        request_json[key_name.lower()] = field_value
+
+                    else:
+                        request_json[key_name.lower()] = None if field_value is None else field_value
+
+                else:
+                    request_json[key_name] = self.set_data(member_detail, field_value)
+
+        return request_json
+
     def is_record_request(self, record_instance, class_detail):
         try:
             from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
@@ -158,56 +200,6 @@ class JSONConverter(Converter):
 
         return request_json
 
-    def is_not_record_request(self, request_instance, class_name, class_detail, instance_number):
-        try:
-            from zcrmsdk.src.com.zoho.crm.api.record import FileDetails
-        except Exception:
-            from ..record import FileDetails
-
-        request_json = {}
-
-        for member_name, member_detail in class_detail.items():
-            modification = None
-
-            if Constants.READ_ONLY in member_name or (Constants.NAME not in member_detail):
-                continue
-
-            try:
-                modification = getattr(request_instance, Constants.IS_KEY_MODIFIED)(member_name)
-            except Exception as e:
-                JSONConverter.logger.info(Constants.EXCEPTION_IS_KEY_MODIFIED + e.__str__())
-
-            if (modification is None or modification == 0) and Constants.REQUIRED in member_detail and bool(
-                    member_detail[Constants.REQUIRED]):
-                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR,
-                                   Constants.MANDATORY_KEY_MISSING_ERROR + member_name)
-
-            field_value = getattr(request_instance,
-                                  self.construct_private_member(class_name=class_name, member_name=member_name))
-
-            if modification is not None and not modification == 0 and self.value_checker(class_name=class_name,
-                                                                                     member_name=member_name,
-                                                                                     key_details=member_detail,
-                                                                                     value=field_value,
-                                                                                     unique_values_map=self.unique_dict,
-                                                                                     instance_number=instance_number) is True:
-                key_name = member_detail.get(Constants.NAME)
-
-                if isinstance(request_instance, FileDetails):
-                    if key_name.lower() == Constants.ATTACHMENT_ID.lower():
-                        request_json[key_name.lower()] = field_value
-
-                    elif key_name.lower() == Constants.FILE_ID.lower():
-                        request_json[key_name.lower()] = field_value
-
-                    else:
-                        request_json[key_name.lower()] = None if field_value is None else field_value
-
-                else:
-                    request_json[key_name] = self.set_data(member_detail, field_value)
-
-        return request_json
-
     def set_data(self, member_detail, field_value):
         if field_value is not None:
             data_type = member_detail[Constants.TYPE]
@@ -234,9 +226,6 @@ class JSONConverter(Converter):
 
         return None
 
-    def append_to_request(self, request_base, request_object):
-        return json.dumps(request_object).encode('utf-8')
-
     def set_json_object(self, field_value, member_detail):
         json_object = {}
         request_object = dict(field_value)
@@ -423,40 +412,6 @@ class JSONConverter(Converter):
 
         return record_instance
 
-    def build_name(self, member_name):
-        name_split = str(member_name).split('_')
-        sdk_name = name_split[0].lower()
-
-        if len(name_split) > 1:
-            for i in range(1, len(name_split)):
-                sdk_name += '_' + name_split[i].lower()
-
-        return sdk_name
-
-    def __get_module_detail_from_user_spec_json(self, module):
-        try:
-            import os
-            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
-        except Exception:
-            import os
-            from ..initializer import Initializer
-
-        record_field_details_path = os.path.join(Initializer.get_initializer().resource_path,
-                                                 Constants.FIELD_DETAILS_DIRECTORY, Converter.get_encoded_file_name())
-
-        record_field_details = Initializer.get_json(record_field_details_path)
-        module_detail = Utility.get_json_object(record_field_details, module)
-
-        return module_detail
-
-    @staticmethod
-    def __get_instance_from_name(class_path):
-        path_split = str(class_path).rpartition('.')
-        imported_module = importlib.import_module(path_split[0])
-        class_holder = getattr(imported_module, path_split[-1])
-
-        return class_holder()
-
     def get_data(self, key_data, member_detail):
         member_value = None
 
@@ -530,6 +485,22 @@ class JSONConverter(Converter):
 
         return values
 
+    def __get_module_detail_from_user_spec_json(self, module):
+        try:
+            import os
+            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+        except Exception:
+            import os
+            from ..initializer import Initializer
+
+        record_field_details_path = os.path.join(Initializer.get_initializer().resource_path,
+                                                 Constants.FIELD_DETAILS_DIRECTORY, Converter.get_encoded_file_name())
+
+        record_field_details = Initializer.get_json(record_field_details_path)
+        module_detail = Utility.get_json_object(record_field_details, module)
+
+        return module_detail
+
     def redirector_for_json_to_object(self, key_data):
         if isinstance(key_data, dict):
             return self.get_map_data(key_data, None)
@@ -608,6 +579,37 @@ class JSONConverter(Converter):
 
         return matches / total_points
 
+    def build_name(self, member_name):
+        name_split = str(member_name).split('_')
+        sdk_name = name_split[0].lower()
+
+        if len(name_split) > 1:
+            for i in range(1, len(name_split)):
+                sdk_name += '_' + name_split[i].lower()
+
+        return sdk_name
+
+    @staticmethod
+    def __get_instance_from_name(class_path):
+        path_split = str(class_path).rpartition('.')
+        imported_module = importlib.import_module(path_split[0])
+        class_holder = getattr(imported_module, path_split[-1])
+
+        return class_holder()
+
+    def module_to_class(self, module_name):
+        class_name = module_name
+
+        if "_" in module_name:
+            class_name = ''
+            module_split = str(module_name).split('_')
+
+            for each_name in module_split:
+                each_name = each_name.capitalize()
+                class_name += each_name
+
+        return class_name
+
     def construct_private_member(self, class_name, member_name):
         return '_' + class_name + '__' + member_name
 
