@@ -1,4 +1,3 @@
-
 try:
     import logging
     import threading
@@ -33,7 +32,6 @@ except Exception:
 
 
 class Utility(object):
-
     """
     This class handles module field details.
     """
@@ -41,20 +39,27 @@ class Utility(object):
     apitype_vs_structurename = {}
     new_file = False
     get_modified_modules = False
+    lock = threading.RLock()
+    logger = logging.getLogger('SDKLogger')
 
     @staticmethod
     def get_fields(module_api_name):
 
         """
         This method to fetch field details of the current module for the current user and store the result in a JSON file.
-        :param module_api_name: A str containing the CRM module API name.
+
+        Parameters:
+            module_api_name (str) : A string containing the CRM module API name.
         """
-        lock = threading.Lock()
 
-        from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+        try:
+            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+        except Exception:
+            from ..initializer import Initializer
 
-        with lock:
-            resources_path = os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY)
+        with Utility.lock:
+            resources_path = os.path.join(Initializer.get_initializer().resource_path,
+                                          Constants.FIELD_DETAILS_DIRECTORY)
 
             if not os.path.exists(resources_path):
                 if Utility.search_json_details(module_api_name) is not None:
@@ -63,15 +68,13 @@ class Utility(object):
 
             record_field_details_path = Utility.get_file_name()
 
-            # if not (os.path.exists(record_field_details_path)) and Utility.search_json_details(module_api_name) is not None:
-            #     return
-
             if os.path.exists(record_field_details_path):
                 record_field_details_json = Initializer.get_json(record_field_details_path)
 
                 if Initializer.get_initializer().auto_refresh_fields and not Utility.new_file and not Utility.get_modified_modules:
                     Utility.get_modified_modules = True
-                    Utility.modify_fields(record_field_details_path, record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] if Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None)
+                    Utility.modify_fields(record_field_details_path, record_field_details_json[
+                        Constants.FIELDS_LAST_MODIFIED_TIME] if Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None)
                     Utility.get_modified_modules = False
 
                 if module_api_name in Initializer.get_json(record_field_details_path):
@@ -97,11 +100,13 @@ class Utility(object):
                 for module in module_api_names:
                     if module not in record_field_details_json:
                         record_field_details_json[module] = {}
-                        Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                        Utility.write_to_file(file_path=record_field_details_path,
+                                              file_contents=record_field_details_json)
                         field_details = Utility.get_fields_details(module)
                         record_field_details_json = Initializer.get_json(record_field_details_path)
                         record_field_details_json[module] = field_details
-                        Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                        Utility.write_to_file(file_path=record_field_details_path,
+                                              file_contents=record_field_details_json)
 
                 Utility.new_file = False
 
@@ -114,38 +119,6 @@ class Utility(object):
                 record_field_details_json[module_api_name] = field_details
                 Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
-    @staticmethod
-    def write_to_file(file_path, file_contents):
-        with open(file_path, mode="w") as file:
-            json.dump(file_contents, file)
-            file.flush()
-            file.close()
-
-    @staticmethod
-    def search_json_details(key):
-        package_name = Constants.PACKAGE_NAMESPACE + 'record.' + key
-
-        from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
-
-        for class_key in Initializer.json_details.keys():
-            if class_key == package_name:
-                return_json = {
-                    Constants.MODULEPACKAGENAME: class_key,
-                    Constants.MODULEDETAILS: Initializer.json_details[class_key]
-                }
-
-                return return_json
-
-        return None
-
-    @staticmethod
-    def get_json_object(json, key):
-        for key_in_json in json.keys():
-            if key_in_json == key:
-                return json[key_in_json]
-
-        return None
-
     @staticmethod
     def modify_fields(record_field_details_path, modified_time):
         modified_modules = Utility.get_modules(modified_time)
@@ -162,61 +135,46 @@ class Utility(object):
             for module in modified_modules:
                 Utility.get_fields(module)
 
-
-    @staticmethod
-    def get_modules(header):
-        import zcrmsdk.src.com.zoho.crm.api.modules as Modules
-
-        api_names = []
-        header_map = HeaderMap()
-        if header is not None:
-            header_value = datetime.datetime.fromtimestamp(header/1000.0)
-            header_map.add(Modules.GetModulesHeader.if_modified_since, header_value)
-
-        response = Modules.ModulesOperations().get_modules(header_map)
-
-        if response is not None:
-            response_object = response.get_object()
-            if isinstance(response_object, Modules.ResponseWrapper):
-                modules = response_object.get_modules()
-                for module in modules:
-                    if module.get_api_supported():
-                        api_names.append(module.get_api_name())
-
-        return api_names
-
     @staticmethod
     def get_file_name():
-        return os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY, Converter.get_encoded_file_name())
+        return os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY,
+                            Converter.get_encoded_file_name())
 
     @staticmethod
     def get_related_lists(related_module_name, module_api_name, common_api_handler):
-        try:
-            is_new_data = False
-            key = module_api_name + Constants.UNDERSCORE + Constants.RELATED_LISTS
-            resources_path = os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY)
+        with Utility.lock:
+            try:
+                is_new_data = False
+                key = module_api_name + Constants.UNDERSCORE + Constants.RELATED_LISTS
+                resources_path = os.path.join(Initializer.get_initializer().resource_path,
+                                              Constants.FIELD_DETAILS_DIRECTORY)
 
-            if not os.path.exists(resources_path):
-                os.makedirs(resources_path)
-            record_field_details_path = Utility.get_file_name()
+                if not os.path.exists(resources_path):
+                    os.makedirs(resources_path)
+                record_field_details_path = Utility.get_file_name()
 
-            if not os.path.exists(record_field_details_path) or (os.path.exists(record_field_details_path) and key not in Initializer.get_json(record_field_details_path)):
-                is_new_data = True
-                related_list_values = Utility.get_related_list_details(module_api_name)
-                record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(record_field_details_path) else {}
-                record_field_details_json[key] = related_list_values
-                Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                if not os.path.exists(record_field_details_path) or (
+                        os.path.exists(record_field_details_path) and key not in Initializer.get_json(
+                    record_field_details_path)):
+                    is_new_data = True
+                    related_list_values = Utility.get_related_list_details(module_api_name)
+                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
+                        record_field_details_path) else {}
+                    record_field_details_json[key] = related_list_values
+                    Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
-            record_field_details_json = Initializer.get_json(record_field_details_path)
-            module_related_list = record_field_details_json[key]
+                record_field_details_json = Initializer.get_json(record_field_details_path)
+                module_related_list = record_field_details_json[key]
 
-            if not Utility.check_related_list_exists(related_module_name, module_related_list, common_api_handler) and not is_new_data:
-                del record_field_details_json[key]
-                Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                if not Utility.check_related_list_exists(related_module_name, module_related_list,
+                                                         common_api_handler) and not is_new_data:
+                    del record_field_details_json[key]
+                    Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
-                Utility.get_related_lists(related_module_name, module_api_name, common_api_handler)
-        except Exception:
-            raise
+                    Utility.get_related_lists(related_module_name, module_api_name, common_api_handler)
+
+            except Exception as e:
+                Utility.logger.info(Constants.EXCEPTION + e.__str__())
 
     @staticmethod
     def check_related_list_exists(related_module_name, module_related_list_array, common_api_handler):
@@ -324,9 +282,135 @@ class Utility(object):
 
         return fields_details
 
+    @staticmethod
+    def search_json_details(key):
+        package_name = Constants.PACKAGE_NAMESPACE + 'record.' + key
+
+        from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+
+        for class_key in Initializer.json_details.keys():
+            if class_key == package_name:
+                return_json = {
+                    Constants.MODULEPACKAGENAME: class_key,
+                    Constants.MODULEDETAILS: Initializer.json_details[class_key]
+                }
+
+                return return_json
+
+        return None
+
+    @staticmethod
+    def get_modules(header):
+
+        import zcrmsdk.src.com.zoho.crm.api.modules as Modules
+
+        api_names = []
+        header_map = HeaderMap()
+        if header is not None:
+            header_value = datetime.datetime.fromtimestamp(header / 1000.0)
+            header_map.add(Modules.GetModulesHeader.if_modified_since, header_value)
+
+        response = Modules.ModulesOperations().get_modules(header_map)
+
+        if response is not None:
+            if response.get_status_code() in [Constants.NO_CONTENT_STATUS_CODE, Constants.NOT_MODIFIED_STATUS_CODE]:
+                return api_names
+
+            response_object = response.get_object()
+
+            if isinstance(response_object, Modules.ResponseWrapper):
+                modules = response_object.get_modules()
+                for module in modules:
+                    if module.get_api_supported():
+                        api_names.append(module.get_api_name())
+
+        return api_names
+
+    @staticmethod
+    def get_json_object(json, key):
+        for key_in_json in json.keys():
+            if key_in_json == key:
+                return json[key_in_json]
+
+        return None
+
+    @staticmethod
+    def set_data_type(field_detail, field, module_api_name):
+        api_type = field.get_data_type()
+        module = ''
+        key_name = field.get_api_name()
+
+        if key_name.lower() == Constants.PRODUCT_DETAILS.lower() and module_api_name in Constants.INVENTORY_MODULES:
+            field_detail[Constants.NAME] = key_name
+            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
+            field_detail[Constants.STRUCTURE_NAME] = Constants.INVENTORY_LINE_ITEMS
+
+            return
+
+        elif key_name.lower() == Constants.PRICING_DETAILS.lower() and module_api_name.lower() == Constants.PRICE_BOOKS.lower():
+            field_detail[Constants.NAME] = key_name
+            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
+            field_detail[Constants.STRUCTURE_NAME] = Constants.PRICINGDETAILS
+
+            return
+
+        elif key_name.lower() == Constants.PARTICIPANT_API_NAME.lower() and (
+                module_api_name.lower() == Constants.EVENTS.lower() or module_api_name.lower() == Constants.ACTIVITIES.lower()):
+            field_detail[Constants.NAME] = key_name
+            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
+            field_detail[Constants.STRUCTURE_NAME] = Constants.PARTICIPANTS
+
+            return
+
+        elif key_name.lower() == Constants.COMMENTS.lower() and module_api_name.lower() == Constants.SOLUTIONS.lower():
+            field_detail[Constants.NAME] = key_name
+            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
+            field_detail[Constants.STRUCTURE_NAME] = Constants.COMMENT_NAMESPACE
+
+            return
+
+        elif key_name.lower() == Constants.LAYOUT.lower():
+            field_detail[Constants.NAME] = key_name
+            field_detail[Constants.TYPE] = Constants.LAYOUT_NAMESPACE
+            field_detail[Constants.STRUCTURE_NAME] = Constants.LAYOUT_NAMESPACE
+
+            return
+
+        elif api_type in Utility.apitype_vs_datatype:
+            field_detail[Constants.TYPE] = Utility.apitype_vs_datatype.get(api_type)
+
+        else:
+            return
+
+        if api_type in Utility.apitype_vs_structurename:
+            field_detail[Constants.STRUCTURE_NAME] = Utility.apitype_vs_structurename.get(api_type)
+
+        if field.get_pick_list_values() is not None and len(field.get_pick_list_values()) > 0:
+            values = list(map(lambda x: x.get_actual_value(), field.get_pick_list_values()))
+
+            field_detail[Constants.VALUES] = values
+
+        if api_type == Constants.SUBFORM:
+            module = field.get_subform().get_module()
+
+            field_detail[Constants.MODULE] = module
+        if api_type == Constants.LOOKUP:
+            module = field.get_lookup().get_module()
+
+            if module is not None and not module == Constants.SE_MODULE:
+                field_detail[Constants.MODULE] = module
+            else:
+                module = ''
+
+        if len(module) > 0:
+            Utility.get_fields(module)
+
+        field_detail[Constants.NAME] = key_name
+
     @staticmethod
     def fill_data_type():
-        field_api_names_string = ["textarea", "text", "website", "email", "phone", "mediumtext", "multiselectlookup", "profileimage"]
+        field_api_names_string = ["textarea", "text", "website", "email", "phone", "mediumtext", "multiselectlookup",
+                                  "profileimage"]
 
         field_api_names_integer = ['integer']
 
@@ -442,73 +526,8 @@ class Utility(object):
             Utility.apitype_vs_structurename[field_api_name] = Constants.REMINDER_NAMESPACE
 
     @staticmethod
-    def set_data_type(field_detail, field_instance, module_api_name):
-        api_type = field_instance.get_data_type()
-        module = ''
-        key_name = field_instance.get_api_name()
-
-        if key_name.lower() == Constants.PRODUCT_DETAILS.lower() and module_api_name in Constants.INVENTORY_MODULES:
-            field_detail[Constants.NAME] = key_name
-            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
-            field_detail[Constants.STRUCTURE_NAME] = Constants.INVENTORY_LINE_ITEMS
-
-            return
-
-        elif key_name.lower() == Constants.PRICING_DETAILS.lower() and module_api_name.lower() == Constants.PRICE_BOOKS.lower():
-            field_detail[Constants.NAME] = key_name
-            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
-            field_detail[Constants.STRUCTURE_NAME] = Constants.PRICINGDETAILS
-
-            return
-
-        elif key_name.lower() == Constants.PARTICIPANT_API_NAME.lower() and (module_api_name.lower() == Constants.EVENTS.lower() or module_api_name.lower() == Constants.ACTIVITIES.lower()):
-            field_detail[Constants.NAME] = key_name
-            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
-            field_detail[Constants.STRUCTURE_NAME] = Constants.PARTICIPANTS
-
-            return
-
-        elif key_name.lower() == Constants.COMMENTS.lower() and module_api_name.lower() == Constants.SOLUTIONS.lower():
-            field_detail[Constants.NAME] = key_name
-            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
-            field_detail[Constants.STRUCTURE_NAME] = Constants.COMMENT_NAMESPACE
-
-            return
-
-        elif key_name.lower() == Constants.LAYOUT.lower():
-            field_detail[Constants.NAME] = key_name
-            field_detail[Constants.TYPE] = Constants.LAYOUT_NAMESPACE
-            field_detail[Constants.STRUCTURE_NAME] = Constants.LAYOUT_NAMESPACE
-
-            return
-
-        elif api_type in Utility.apitype_vs_datatype:
-            field_detail[Constants.TYPE] = Utility.apitype_vs_datatype.get(api_type)
-
-        else:
-            return
-
-        if api_type in Utility.apitype_vs_structurename:
-            field_detail[Constants.STRUCTURE_NAME] = Utility.apitype_vs_structurename.get(api_type)
-
-        if field_instance.get_pick_list_values() is not None and len(field_instance.get_pick_list_values()) > 0:
-            values = list(map(lambda x: x.get_actual_value(), field_instance.get_pick_list_values()))
-
-            field_detail[Constants.VALUES] = values
-
-        if api_type == Constants.SUBFORM:
-            module = field_instance.get_subform().get_module()
-
-            field_detail[Constants.MODULE] = module
-        if api_type == Constants.LOOKUP:
-            module = field_instance.get_lookup().get_module()
-
-            if module is not None and not module == Constants.SE_MODULE:
-                field_detail[Constants.MODULE] = module
-            else:
-                module = ''
-
-        if len(module) > 0:
-            Utility.get_fields(module)
-
-        field_detail[Constants.NAME] = key_name
+    def write_to_file(file_path, file_contents):
+        with open(file_path, mode="w") as file:
+            json.dump(file_contents, file)
+            file.flush()
+            file.close()
